autowisp.database.data_model.hdf5_links module — AutoWISP documentation

# autowisp.database.data_model.hdf5_links module

## Class Inheritance Diagram

Define the hdf5_links table.

class autowisp.database.data_model.hdf5_links.HDF5Link(**kwargs)

  Bases: `DataModelBase`

  Table describing links of chosen versions of products in HDF5 files.

  abspath

    The full absolute path to the link in the HDF5 file.

  description

    A brief description of what this attribute tracks.

  hdf5_structure_version_id

    Which structure version of which pipeline product is this element configuration for.

  id

    A unique identifier for each row.

  pipeline_key

    How is this link referred to by the pipeline.

  structure_version
  target

    The full absolute path the link should point to.

  timestamp

    When record was last changed